aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/install
diff options
context:
space:
mode:
authorMeik Sievertsen <acydburn@phpbb.com>2009-05-01 10:06:41 +0000
committerMeik Sievertsen <acydburn@phpbb.com>2009-05-01 10:06:41 +0000
commit864c63406078cc2b4a7ea2e256598c3c5a86f265 (patch)
tree132281f1625032dbd963d4d6b22209c8fd58ed44 /phpBB/install
parent2e4174da2a6789aa0125ba214588deaa4c635d0f (diff)
downloadforums-864c63406078cc2b4a7ea2e256598c3c5a86f265.tar
forums-864c63406078cc2b4a7ea2e256598c3c5a86f265.tar.gz
forums-864c63406078cc2b4a7ea2e256598c3c5a86f265.tar.bz2
forums-864c63406078cc2b4a7ea2e256598c3c5a86f265.tar.xz
forums-864c63406078cc2b4a7ea2e256598c3c5a86f265.zip
Set new version...
git-svn-id: file:///svn/phpbb/branches/phpBB-3_0_0@9503 89ea8834-ac86-4346-8a33-228a782c2dd0
Diffstat (limited to 'phpBB/install')
-rw-r--r--phpBB/install/database_update.php6
-rw-r--r--phpBB/install/schemas/schema_data.sql2
2 files changed, 4 insertions, 4 deletions
diff --git a/phpBB/install/schemas/schema_data.sql b/phpBB/install/schemas/schema_data.sql
index 759cfb1758..6deebd9005 100644
--- a/phpBB/install/schemas/schema_data.sql
+++ b/phpBB/install/schemas/schema_data.sql
@@ -222,7 +222,7 @@ INSERT INTO phpbb_config (config_name, config_value) VALUES ('topics_per_page',
INSERT INTO phpbb_config (config_name, config_value) VALUES ('tpl_allow_php', '0');
INSERT INTO phpbb_config (config_name, config_value) VALUES ('upload_icons_path', 'images/upload_icons');
INSERT INTO phpbb_config (config_name, config_value) VALUES ('upload_path', 'files');
-INSERT INTO phpbb_config (config_name, config_value) VALUES ('version', '3.0.5-dev');
+INSERT INTO phpbb_config (config_name, config_value) VALUES ('version', '3.0.5-RC1');
INSERT INTO phpbb_config (config_name, config_value) VALUES ('warnings_expire_days', '90');
INSERT INTO phpbb_config (config_name, config_value) VALUES ('warnings_gc', '14400');
diff --git a/phpBB/install/database_update.php b/phpBB/install/database_update.php
index e79ea717cf..ee28799694 100644
--- a/phpBB/install/database_update.php
+++ b/phpBB/install/database_update.php
@@ -8,7 +8,7 @@
*
*/
-$updates_to_version = '3.0.5-dev';
+$updates_to_version = '3.0.5-RC1';
// Enter any version to update from to test updates. The version within the db will not be updated.
$debug_from_version = false;
@@ -666,7 +666,7 @@ function database_update_info()
// Changes from 3.0.4-RC1 to 3.0.4
'3.0.4-RC1' => array(),
// Changes from 3.0.4 to 3.0.5-dev
'3.0.4' => array(
'change_columns' => array(
FORUMS_TABLE => array(
@@ -893,7 +893,7 @@ function change_database_data(&$no_updates, $version)
case '3.0.4-RC1':
break;
// Changes from 3.0.4 to 3.0.5-dev
case '3.0.4':
// Captcha config variables
@@ -666,7 +666,7 @@ function database_update_info()
// Changes from 3.0.4-RC1 to 3.0.4
'3.0.4-RC1' => array(),
- // Changes from 3.0.4 to 3.0.5-dev
+ // Changes from 3.0.4 to 3.0.5-RC1
'3.0.4' => array(
'change_columns' => array(
@@ -893,7 +893,7 @@ function change_database_data(&$no_updates, $version)
case '3.0.4-RC1':
break;
- // Changes from 3.0.4 to 3.0.5-dev
+ // Changes from 3.0.4 to 3.0.5-RC1
case '3.0.4':
// Captcha config variables